# PPTX Extractor MCP Server 使用指南

## 项目概述

PPTX Extractor 是一个基于 Model Context Protocol (MCP) 的服务器，专门用于解析 PowerPoint (PPTX) 文件并将其转换为适合 Marp CLI 的 Markdown 格式。该服务器提供了完整的工具集，包括内容提取、格式转换和样式生成。

## 功能特性

✅ **已完成的功能：**
- PPTX 文件解析和内容提取
- 生成 Marp CLI 兼容的 Markdown 格式
- 生成配套的 CSS 样式文件
- 支持结构化输出（JSON 格式）
- 完整的错误处理和验证
- 单元测试覆盖
- MCP 协议集成

## 环境要求

- Python 3.10+
- 依赖包：mcp[cli], python-pptx, pydantic

## 安装和设置

### 1. 创建虚拟环境

```bash
python3 -m venv venv
source venv/bin/activate  # Linux/Mac
# 或
venv\Scripts\activate  # Windows
```

### 2. 安装依赖

```bash
pip install -i https://mirrors.aliyun.com/pypi/simple/ mcp[cli] python-pptx pydantic
```

### 3. 验证安装

```bash
python -c "from pptx_extractor import PPTXExtractor; print('安装成功！')"
```

## 使用方法

### 方法一：直接使用 Python 脚本

```python
from pptx_extractor import extract_pptx_to_marp, extract_pptx_to_files

# 提取内容到内存
result = extract_pptx_to_marp("path/to/your/presentation.pptx")
print(f"标题: {result.title}")
print(f"幻灯片数量: {result.slide_count}")
print(f"Markdown 内容长度: {len(result.markdown_content)}")
print(f"CSS 内容长度: {len(result.css_content)}")

# 保存到文件
file_result = extract_pptx_to_files("path/to/your/presentation.pptx", "output_directory")
print(file_result["message"])
```

### 方法二：使用 MCP 开发模式

```bash
# 启动开发服务器
mcp dev pptx_extractor.py

# 在另一个终端中测试
mcp dev pptx_extractor.py --with-editable .
```

### 方法三：安装到 Claude Desktop

```bash
# 安装 MCP 服务器到 Claude Desktop
mcp install pptx_extractor.py --name "PPTX Extractor"

# 或者使用自定义名称
mcp install pptx_extractor.py --name "我的 PPTX 转换器"
```

### 方法四：直接运行服务器

```bash
# 直接运行
python pptx_extractor.py

# 或者使用 MCP 运行
mcp run pptx_extractor.py
```

## 可用工具

### 1. extract_pptx_to_marp

**功能：** 提取 PPTX 文件内容并转换为 Marp 格式

**参数：**
- `pptx_path` (str): PPTX 文件路径

**返回：**
- `markdown_content` (str): Marp 兼容的 Markdown 内容
- `css_content` (str): 配套的 CSS 样式
- `slide_count` (int): 幻灯片数量
- `title` (str): 演示文稿标题

**示例：**
```python
result = extract_pptx_to_marp("presentation.pptx")
print(result.markdown_content)
print(result.css_content)
```

### 2. extract_pptx_to_files

**功能：** 提取 PPTX 内容并保存到文件

**参数：**
- `pptx_path` (str): PPTX 文件路径
- `output_dir` (str, 可选): 输出目录，默认为当前目录

**返回：**
- `markdown_file` (str): 生成的 Markdown 文件路径
- `css_file` (str): 生成的 CSS 文件路径
- `slide_count` (int): 幻灯片数量
- `title` (str): 演示文稿标题
- `message` (str): 操作结果消息

**示例：**
```python
result = extract_pptx_to_files("presentation.pptx", "output")
print(f"Markdown 文件: {result['markdown_file']}")
print(f"CSS 文件: {result['css_file']}")
```

### 3. get_pptx_info (资源)

**功能：** 获取 PPTX 文件的基本信息

**参数：**
- `file_path` (str): PPTX 文件路径

**返回：** JSON 格式的文件信息

**示例：**
```python
# 通过 MCP 资源访问
# pptx://path/to/file.pptx
```

## 输出格式

### Markdown 格式

生成的 Markdown 文件包含以下特性：
- Marp 兼容的前置元数据
- 幻灯片分隔符 (`---`)
- 标题和内容结构
- 支持列表和基本格式

示例：
```markdown
---
marp: true
theme: default
title: 演示文稿标题
author: PPTX Extractor
paginate: true
backgroundColor: #fff
color: #333
---

# 第一张幻灯片标题

幻灯片内容...

---

# 第二张幻灯片标题

更多内容...
```

### CSS 样式

生成的 CSS 文件包含：
- 响应式设计
- 现代化的视觉样式
- 中文字体支持
- 表格、列表、代码块样式
- 移动设备适配

## 测试

运行单元测试：

```bash
# 安装测试依赖
pip install -i https://mirrors.aliyun.com/pypi/simple/ pytest pytest-asyncio

# 运行测试
python -m pytest test_pptx_extractor.py -v
```

## 错误处理

服务器包含完整的错误处理机制：

- **文件不存在：** 抛出 `FileNotFoundError`
- **非 PPTX 文件：** 抛出 `ValueError`
- **依赖缺失：** 抛出 `ImportError`
- **解析错误：** 返回错误信息

## 与 Marp CLI 集成

生成的 Markdown 和 CSS 文件可以直接与 Marp CLI 配合使用：

```bash
# 安装 Marp CLI
npm install -g @marp-team/marp-cli

# 使用生成的 Markdown 文件
marp presentation_marp.md --html

# 使用自定义 CSS
marp presentation_marp.md --css presentation_marp.css --html

# 生成 PDF
marp presentation_marp.md --pdf
```

## 项目结构

```
MCP/
├── pptx_extractor.py          # 主服务器文件
├── test_pptx_extractor.py     # 单元测试
├── pyproject.toml             # 项目配置
├── PPTX/                      # 示例 PPTX 文件
│   ├── 第1课时教案_marp.pptx
│   └── 第1课时教案_marp.md
├── example_client.py          # 示例客户端
├── install.py                 # 安装脚本
└── USAGE_GUIDE.md            # 本使用指南
```

## 故障排除

### 常见问题

1. **ImportError: No module named 'pptx'**
   ```bash
   pip install -i https://mirrors.aliyun.com/pypi/simple/ python-pptx
   ```

2. **MCP 命令未找到**
   ```bash
   pip install -i https://mirrors.aliyun.com/pypi/simple/ mcp[cli]
   ```

3. **文件权限错误**
   ```bash
   chmod +x pptx_extractor.py
   ```

4. **中文显示问题**
   - 确保系统支持中文字体
   - 检查文件编码为 UTF-8

### 调试模式

```bash
# 启用详细日志
python -u pptx_extractor.py

# 使用 MCP 开发模式进行调试
mcp dev pptx_extractor.py --with-editable .
```

## 扩展和定制

### 自定义样式

可以修改 `_generate_css()` 方法来定制 CSS 样式：

```python
def _generate_css(self) -> str:
    # 自定义 CSS 生成逻辑
    css_lines = [
        "/* 自定义样式 */",
        "section {",
        "  background: linear-gradient(45deg, #667eea 0%, #764ba2 100%);",
        "  color: white;",
        "}",
        # ... 更多样式
    ]
    return "\n".join(css_lines)
```

### 添加新的输出格式

可以扩展 `PPTXExtractor` 类来支持其他输出格式：

```python
def generate_html(self) -> str:
    """生成 HTML 格式输出"""
    # HTML 生成逻辑
    pass

def generate_pdf(self) -> bytes:
    """生成 PDF 格式输出"""
    # PDF 生成逻辑
    pass
```

## 贡献指南

1. Fork 项目
2. 创建功能分支
3. 提交更改
4. 运行测试
5. 创建 Pull Request

## 许可证

本项目采用 MIT 许可证。

## 支持

如有问题或建议，请：
1. 查看本文档
2. 运行测试确认问题
3. 提交 Issue 或 Pull Request

---

**注意：** 本项目已完成所有要求的功能，包括 PPTX 解析、Marp 格式转换、CSS 样式生成和 MCP 服务器集成。所有功能都经过测试验证，可以立即使用。 